aboutsummaryrefslogtreecommitdiffstats
path: root/camel/providers/imap/camel-imap-private.h
diff options
context:
space:
mode:
Diffstat (limited to 'camel/providers/imap/camel-imap-private.h')
-rw-r--r--camel/providers/imap/camel-imap-private.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/camel/providers/imap/camel-imap-private.h b/camel/providers/imap/camel-imap-private.h
index c7af3ee5e6..811efc5576 100644
--- a/camel/providers/imap/camel-imap-private.h
+++ b/camel/providers/imap/camel-imap-private.h
@@ -54,13 +54,14 @@ struct _CamelImapStorePrivate {
struct _CamelImapFolderPrivate {
#ifdef ENABLE_THREADS
- GMutex *search_lock; /* for locking the search object */
+ EMutex *search_lock; /* for locking the search object */
+ EMutex *cache_lock; /* for locking the cache object */
#endif
};
#ifdef ENABLE_THREADS
-#define CAMEL_IMAP_FOLDER_LOCK(f, l) (g_mutex_lock(((CamelImapFolder *)f)->priv->l))
-#define CAMEL_IMAP_FOLDER_UNLOCK(f, l) (g_mutex_unlock(((CamelImapFolder *)f)->priv->l))
+#define CAMEL_IMAP_FOLDER_LOCK(f, l) (e_mutex_lock(((CamelImapFolder *)f)->priv->l))
+#define CAMEL_IMAP_FOLDER_UNLOCK(f, l) (e_mutex_unlock(((CamelImapFolder *)f)->priv->l))
#else
#define CAMEL_IMAP_FOLDER_LOCK(f, l)
#define CAMEL_IMAP_FOLDER_UNLOCK(f, l)